@@ -2,8 +2,14 @@
 # -*- coding: utf-8 -*-
 
 __author__ = 'Thomas Sterren'
-__contributors__ = []
-__version__ = '0.2.0'
+__contributors__ = ['Martin Meyer']
+__version__ = '2.0.0'
+
+
+def main():
+    print(__version__)
+
 
 if __name__ == '__main__':
-    print(__version__)
+    main()
+
